@@ -870,8 +870,9 @@ configureDhcp6Server(Dhcpv6Srv& server, isc::data::ConstElementPtr config_set,
     LOG_DEBUG(dhcp6_logger, DBG_DHCP6_COMMAND, DHCP6_CONFIG_START)
         .arg(server.redactConfig(config_set)->str());
 
+    std::unique_ptr<MtTestMode> mt_test_mode;
     if (check_only) {
-        MultiThreadingMgr::instance().setTestMode(true);
+        mt_test_mode.reset(new MtTestMode());
     }
 
     auto answer = processDhcp6Config(config_set);
