@@ -17,9 +17,16 @@
 
 #include <map>
 
+#ifdef WDEPRECATED_LITERAL_OPERATOR_FLAG_SUPPORTED
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-literal-operator"
+#endif
 // #include <sysrepo-cpp/Changes.hpp>  // Will be required on newer sysrepo-cpp
 #include <sysrepo-cpp/Session.hpp>
 // #include <sysrepo-cpp/Subscription.hpp>  // Will be required on newer sysrepo-cpp
+#ifdef WDEPRECATED_LITERAL_OPERATOR_FLAG_SUPPORTED
+#pragma GCC diagnostic pop
+#endif
 
 namespace isc {
 namespace netconf {
