@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2024 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -93,7 +93,9 @@ public:
     ~ProcessSpawnImpl();
 
     /// @brief Returns full command line, including arguments, for the process.
-    std::string getCommandLine() const;
+    ///
+    /// @param redact_args list of arguments to redact.
+    std::string getCommandLine(std::unordered_set<std::string> redact_args = {}) const;
 
     /// @brief Spawn the new process.
     ///
@@ -316,15 +318,26 @@ ProcessSpawnImpl::~ProcessSpawnImpl() {
 }
 
 std::string
-ProcessSpawnImpl::getCommandLine() const {
+ProcessSpawnImpl::getCommandLine(std::unordered_set<std::string> redact_args /* = {} */) const {
     std::ostringstream s;
     s << executable_;
     // Start with index 1, because the first argument duplicates the
     // path to the executable. Note, that even if there are no parameters
     // the minimum size of the table is 2.
     int i = 1;
+    bool redact_next = false;
     while (args_[i] != NULL) {
-        s << " " << args_[i];
+        if (redact_next) {
+            s << " " << "*****";
+            redact_next = false;
+        } else {
+            if (redact_args.count(args_[i])) {
+                redact_next = true;
+            }
+
+            s << " " << args_[i];
+        }
+
         ++i;
     }
     return (s.str());
@@ -489,8 +502,8 @@ ProcessSpawn::ProcessSpawn(const SpawnMode mode,
 }
 
 std::string
-ProcessSpawn::getCommandLine() const {
-    return (impl_->getCommandLine());
+ProcessSpawn::getCommandLine(std::unordered_set<std::string> redact_args /* = {} */) const {
+    return (impl_->getCommandLine(redact_args));
 }
 
 pid_t
