@@ -6,6 +6,7 @@
 
 #include <config.h>
 
+#include <cc/command_interpreter.h>
 #include <dhcp/libdhcp++.h>
 #include <dhcp/option_custom.h>
 #include <dhcpsrv/cfgmgr.h>
@@ -29,6 +30,7 @@
 #include <time.h>
 
 using namespace isc::asiolink;
+using namespace isc::config;
 using namespace isc::data;
 using namespace isc::db;
 using namespace isc::dhcp;
@@ -84,6 +86,9 @@ LeaseMgr::recountLeaseStats4() {
     // Cumulative counters ("reclaimed-declined-addresses", "reclaimed-leases",
     // "cumulative-assigned-addresses") never get zeroed.
     int64_t zero = 0;
+
+    stats_mgr.setValue("assigned-addresses", zero);
+
     stats_mgr.setValue("declined-addresses", zero);
 
     // Create if it does not exit reclaimed declined leases global stats.
@@ -164,6 +169,9 @@ LeaseMgr::recountLeaseStats4() {
     LeaseStatsRow row;
     while (query->getNextRow(row)) {
         if (row.lease_state_ == Lease::STATE_DEFAULT) {
+            // Add to the global value.
+            stats_mgr.addValue("assigned-addresses", row.state_count_);
+
             // Add to subnet level value.
             stats_mgr.addValue(StatsMgr::generateName("subnet", row.subnet_id_,
                                                       "assigned-addresses"),
@@ -174,6 +182,9 @@ LeaseMgr::recountLeaseStats4() {
                                                       "declined-addresses"),
                                row.state_count_);
 
+            // Add to the global value.
+            stats_mgr.addValue("assigned-addresses", row.state_count_);
+
             // Add to the global value.
             stats_mgr.addValue("declined-addresses", row.state_count_);
 
@@ -295,6 +306,11 @@ LeaseMgr::recountLeaseStats6() {
     // "cumulative-assigned-nas", "cumulative-assigned-pds",
     // "cumulative-registered-nas")) never get zeroed.
     int64_t zero = 0;
+
+    stats_mgr.setValue("assigned-nas", zero);
+
+    stats_mgr.setValue("assigned-pds", zero);
+
     stats_mgr.setValue("declined-addresses", zero);
 
     if (!stats_mgr.getObservation("reclaimed-declined-addresses")) {
@@ -420,6 +436,9 @@ LeaseMgr::recountLeaseStats6() {
         switch(row.lease_type_) {
             case Lease::TYPE_NA:
                 if (row.lease_state_ == Lease::STATE_DEFAULT) {
+                    // Add to the global value.
+                    stats_mgr.addValue("assigned-nas", row.state_count_);
+
                     // Add to subnet level value.
                     stats_mgr.addValue(StatsMgr::generateName("subnet", row.subnet_id_,
                                                               "assigned-nas"),
@@ -430,6 +449,9 @@ LeaseMgr::recountLeaseStats6() {
                                                               "declined-addresses"),
                                        row.state_count_);
 
+                    // Add to the global value.
+                    stats_mgr.addValue("assigned-nas", row.state_count_);
+
                     // Add to the global value.
                     stats_mgr.addValue("declined-addresses", row.state_count_);
 
@@ -448,6 +470,9 @@ LeaseMgr::recountLeaseStats6() {
 
             case Lease::TYPE_PD:
                 if (row.lease_state_ == Lease::STATE_DEFAULT) {
+                    // Add to the global value.
+                    stats_mgr.addValue("assigned-pds", row.state_count_);
+
                     // Set subnet level value.
                     stats_mgr.setValue(StatsMgr::generateName("subnet", row.subnet_id_,
                                                               "assigned-pds"),
@@ -1281,5 +1306,17 @@ LeaseMgr::byRemoteId6size() const {
     return (0);
 }
 
+ElementPtr
+LeaseMgr::getStatus() const {
+    return (ElementPtr());
+}
+
+ConstElementPtr
+LeaseMgr::lfcStartHandler() {
+    ostringstream msg;
+    msg << "lease backend '" << getName() << "' is not 'memfile'";
+    return (createAnswer(CONTROL_RESULT_COMMAND_UNSUPPORTED, msg.str()));
+}
+
 } // namespace isc::dhcp
 } // namespace isc
