@@ -10,9 +10,16 @@
 #include <cc/data.h>
 #include <yang/netconf_error.h>
 
+#ifdef WDEPRECATED_LITERAL_OPERATOR_FLAG_SUPPORTED
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-literal-operator"
+#endif
 #include <sysrepo-cpp/Connection.hpp>
 #include <sysrepo-cpp/Enum.hpp>
 #include <sysrepo-cpp/Session.hpp>
+#ifdef WDEPRECATED_LITERAL_OPERATOR_FLAG_SUPPORTED
+#pragma GCC diagnostic pop
+#endif
 
 #include <unordered_map>
 
